@@ -5,7 +5,7 @@ import cPickle
 
 from gargoyle_launcher_gui import *
 
-CURRENTVERSION = "0.1.2"
+CURRENTVERSION = "0.1.3"
 
 class GLaunch(QtGui.QMainWindow):
     games_dict = {}
@@ -18,7 +18,6 @@ class GLaunch(QtGui.QMainWindow):
         self.ui.setupUi(self)
         self.setup_settings()
         #connect buttons
-        QtCore.QObject.connect(self.ui.pushButtonBrowse, QtCore.SIGNAL('clicked()'), self.doBrowse)
         QtCore.QObject.connect(self.ui.pushButtonAddGame, QtCore.SIGNAL('clicked()'), self.doAddGame)
         QtCore.QObject.connect(self.ui.pushButtonDelete, QtCore.SIGNAL('clicked()'), self.doDelGame)
         QtCore.QObject.connect(self.ui.pushButtonLaunch, QtCore.SIGNAL('clicked()'), self.doLaunch)
@@ -26,31 +25,25 @@ class GLaunch(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
         self.load_settings()
         
-        if(self.closeOnExit):
-            self.ui.checkBoxShutdown.setCheckState(QtCore.Qt.Checked)
-        else:
-            self.ui.checkBoxShutdown.setCheckState(QtCore.Qt.Unchecked)
-
-
-    def doBrowse(self):
-        self.fileName = QtGui.QFileDialog.getOpenFileName(self, "Open", self.ui.lineEditPath.text(), "All Files (*)")
-        self.ui.lineEditPath.setText(self.fileName)
-        self.baseName = QtCore.QFileInfo(self.fileName).baseName()
 
     def doLaunch(self):
         os.system("cd /home/user/MyDocs/ && /usr/bin/gargoyle \"" 
                     + str(self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()]) 
                     + "\" &")
 
-        if(self.ui.checkBoxShutdown.isChecked()):
+        if(self.closeOnExit):
             self.close()
 
 
     def doAddGame(self):
-        print self.baseName
-        if not self.baseName in self.games_dict:
-            self.games_dict[self.baseName] = self.fileName
-            self.ui.listWidgetGames.addItem(self.baseName)
+        self.fileName = QtGui.QFileDialog.getOpenFileName(self, "Open", self.lastpath, "All Files (*)")
+        if( self.fileName ):         
+            self.lastpath = self.fileName
+            self.baseName = QtCore.QFileInfo(self.fileName).baseName()
+
+            if not self.baseName in self.games_dict:
+                self.games_dict[self.baseName] = self.fileName
+                self.ui.listWidgetGames.addItem(self.baseName)
 
     def doDelGame(self):
         del self.games_dict[self.ui.listWidgetGames.item(self.ui.listWidgetGames.currentRow()).text()]
@@ -65,8 +58,7 @@ class GLaunch(QtGui.QMainWindow):
 
     def load_settings(self):
         try:
-            self.ui.lineEditPath.setText(str(self.settings.value("last_path").toString()))
-            self.closeOnExit = self.settings.value("close_on_exit").toBool()
+            self.lastpath = str(self.settings.value("last_path").toString())
 
             self.games_dict = cPickle.loads(str(self.settings.value("games_dict").toString()))
             for names in self.games_dict:
@@ -75,13 +67,12 @@ class GLaunch(QtGui.QMainWindow):
 
         except:
             print "firstRun... no Savefile found"
-            self.ui.lineEditPath.setText("/home/user/MyDocs/.documents/")
+            self.lastpath = "/home/user/MyDocs/.documents/"
 
 
     def closeEvent(self, event):
         print "closing"        
-        self.settings.setValue("last_path", self.ui.lineEditPath.text())
-        self.settings.setValue("close_on_exit", self.ui.checkBoxShutdown.isChecked())
+        self.settings.setValue("last_path", self.lastpath)
         
         saveData = cPickle.dumps(self.games_dict)
         self.settings.setValue("games_dict", saveData)
